==> 0.2.0.tar.gz: skillparts/mirzaev/skillparts/system/controllers/SiteController.php <==
<?php

namespace app\controllers;

use Yii;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\Response;
use yii\filters\VerbFilter;
use app\models\AuthenticationForm;
use app\models\RegistrationForm;
use app\models\ContactForm;
use app\models\Account;

class SiteController extends Controller
{

    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'only' => ['logout'],
                'rules' => [
                    [
                        'actions' => ['logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::class,
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Displays homepage.
     *
     * @return string
     */
    public function actionIndex()
    {
        return $this->render('index');
    }

    /**
     * Identification action.
     *
     * @return Response
     */
    public function actionIdentification()
    {
        if (Yii::$app->request->isAjax) {
            Yii::$app->response->format = Response::FORMAT_JSON;

            if (Yii::$app->user->isGuest) {
                return [
                    'menu' => '<a onclick="authentication()">Вход</a>',
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            } else {
                $mail = Yii::$app->user->identity->mail;

                return [
                    'menu' => <<<HTML
                        <p class="m-0">
                            <a class="text-dark" href="/cart"><i class="fas fa-shopping-cart mr-4"></i></a>
                            <a class="text-dark" href="/orders"><i class="fas fa-list mr-4"></i></a>
                            <a class="text-dark" onclick="deauthentication()">Выход ($mail)</a>
                        </p>
                    HTML,
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }
        }
    }

    /**
     * Login action.
     *
     * @return Response|string
     */
    public function actionAuthentication()
    {
        $model = new AuthenticationForm(Yii::$app->request->post()['AuthenticationForm'] ?? Yii::$app->request->get()['AuthenticationForm']);

        if (Yii::$app->request->isAjax) {
            // AJAX-POST-запрос

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже авторизован
                Yii::$app->response->statusCode = 403;
                return [
                    'form' => $this->renderPartial('index'),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }

            Yii::$app->response->format = Response::FORMAT_JSON;

            if (isset($model->mail, $model->pswd)) {
                if ($model->load(Yii::$app->request->post()) && $model->authentication()) {
                    return [
                        'menu' => <<<HTML
                            <p class="m-0">
                                <a class="text-dark" href="/cart"><i class="fas fa-shopping-cart mr-4"></i></a>
                                <a class="text-dark" href="/orders"><i class="fas fa-list mr-4"></i></a>
                                <a class="text-dark" onclick="deauthentication()">Выход ($model->mail)</a>
                            </p>
                        HTML,
                        'form' => $this->renderPartial('index'),
                        '_csrf' => Yii::$app->request->getCsrfToken()
                    ];
                }
            } else {
                return [
                    'menu' => '<a onclick="authentication()">Вход</a>',
                    'form' => $this->renderPartial('authentication', compact('model')),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }
        } else if (Yii::$app->request->isPost) {
            // POST-запрос
        } else {
            // GET-запрос и прочие

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже авторизован
                Yii::$app->response->redirect('/');
            }
        }

        return $this->render('authentication', compact('model'));
    }

    /**
     * Logout action.
     *
     * @return Response
     */
    public function actionDeauthentication()
    {
        if (Yii::$app->request->isAjax) {
            // AJAX-POST-запрос

            Yii::$app->response->format = Response::FORMAT_JSON;
            Yii::$app->user->logout();

            return [
                'menu' => '<a onclick="authentication()">Вход</a>',
                'form' => $this->renderPartial('index'),
                '_csrf' => Yii::$app->request->getCsrfToken()
            ];
        }

        Yii::$app->response->redirect('/');
    }

    /**
     * Login action.
     *
     * @return Response|string
     */
    public function actionRegistration()
    {
        $model = new RegistrationForm(Yii::$app->request->post()['RegistrationForm'] ?? Yii::$app->request->get()['RegistrationForm']);

        if (Yii::$app->request->isAjax) {
            // AJAX-POST-запрос

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже авторизован
                Yii::$app->response->statusCode = 302;
                return [
                    'form' => $this->renderPartial('index'),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }

            Yii::$app->response->format = Response::FORMAT_JSON;

            if (isset($model->mail, $model->pswd)) {
                // Аккаунт передал необходимые параметры

                // Инициализация нового аккаунта
                $account = new Account();
                $account->mail = $model->mail;
                $account->pswd = Yii::$app->security->generatePasswordHash($model->pswd);

                if ($model->load(Yii::$app->request->post()) && $model->validate() && $account->save()) {
                    // Данные прошли проверку и аккаунт был создан

                    return [
                        'menu' => <<<HTML
                            <p class="m-0">
                                <a class="text-dark" href="/cart"><i class="fas fa-shopping-cart mr-4"></i></a>
                                <a class="text-dark" href="/orders"><i class="fas fa-list mr-4"></i></a>
                                <a class="text-dark" onclick="deauthentication()">Выход ($account->mail)</a>
                            </p>
                        HTML,
                        'form' => $this->renderPartial('index'),
                        '_csrf' => Yii::$app->request->getCsrfToken()
                    ];
                } else {
                    // Данные не прошли проверку

                    Yii::$app->response->statusCode = 400;

                    return [
                        'form' => $this->renderPartial('registration', compact('model')),
                        '_csrf' => Yii::$app->request->getCsrfToken()
                    ];
                }
            } else {
                // Аккаунт не передал необходимые параметры

                return [
                    'menu' => '<a onclick="authentication()">Вход</a>',
                    'form' => $this->renderPartial('registration', compact('model')),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }
        } else if (Yii::$app->request->isPost) {
            // POST-запрос
            return;
        } else {
            // GET-запрос и прочие

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже авторизован
                Yii::$app->response->redirect('/');
            }
        }

        return $this->render('registration', compact('model'));
    }

    /**
     * Displays contact page.
     *
     * @return Response|string
     */
    public function actionContact()
    {
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post()) && $model->contact(Yii::$app->params['adminEmail'])) {
            Yii::$app->session->setFlash('contactFormSubmitted');

            return $this->refresh();
        }
        return $this->render('contact', [
            'model' => $model,
        ]);
    }

    /**
     * Displays about page.
     *
     * @return string
     */
    public function actionAbout()
    {
        return $this->render('about');
    }
}

==> 0.3.0.tar.gz: skillparts/mirzaev/skillparts/system/controllers/SiteController.php <==
<?php

namespace app\controllers;

use Yii;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\Response;
use yii\filters\VerbFilter;
use app\models\AccountForm;
use app\models\ContactForm;

class SiteController extends Controller
{

    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'only' => ['logout'],
                'rules' => [
                    [
                        'actions' => ['logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::class,
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Displays homepage.
     *
     * @return string
     */
    public function actionIndex()
    {
        return $this->render('index');
    }

    /**
     * Identification action.
     *
     * @return Response
     */
    public function actionIdentification()
    {
        if (Yii::$app->request->isAjax) {
            Yii::$app->response->format = Response::FORMAT_JSON;

            if (Yii::$app->user->isGuest) {
                return [
                    'menu' => '<a onclick="authentication()">Вход</a>',
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            } else {
                $mail = Yii::$app->user->identity->mail;

                return [
                    'menu' => <<<HTML
                        <p class="m-0">
                            <a class="text-dark" href="/cart"><i class="fas fa-shopping-cart mr-4"></i></a>
                            <a class="text-dark" href="/orders"><i class="fas fa-list mr-4"></i></a>
                            <a class="text-dark" onclick="deauthentication()">Выход ($mail)</a>
                        </p>
                    HTML,
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }
        }
    }

    /**
     * Login action.
     *
     * @return Response|string
     */
    public function actionAuthentication()
    {
        $model = new AccountForm(Yii::$app->request->post()['AccountForm'] ?? Yii::$app->request->get()['AccountForm'] ?? null);

        if (Yii::$app->request->isAjax) {
            // AJAX-POST-запрос

            Yii::$app->response->format = Response::FORMAT_JSON;

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже аутентифицирован
                Yii::$app->response->statusCode = 403;
                return [
                    'form' => $this->renderPartial('index'),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }

            if ($model->authentication()) {
                // Данные прошли проверку

                return [
                    'menu' => <<<HTML
                        <p class="m-0">
                            <a class="text-dark" href="/cart"><i class="fas fa-shopping-cart mr-4"></i></a>
                            <a class="text-dark" href="/orders"><i class="fas fa-list mr-4"></i></a>
                            <a class="text-dark" onclick="deauthentication()">Выход ($model->mail)</a>
                        </p>
                    HTML,
                    'form' => $this->renderPartial('index'),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            } else {
                // Данные не прошли проверку

                Yii::$app->response->statusCode = 400;

                return [
                    'form' => $this->renderPartial('account', compact('model')),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }
        } else if (Yii::$app->request->isPost) {
            // POST-запрос
        } else {
            // GET-запрос и прочие

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже аутентифицирован
                Yii::$app->response->redirect('/');
            }
        }

        return $this->render('authentication', compact('model'));
    }

    /**
     * Logout action.
     *
     * @return Response
     */
    public function actionDeauthentication()
    {
        if (Yii::$app->request->isAjax) {
            // AJAX-POST-запрос

            Yii::$app->response->format = Response::FORMAT_JSON;
            Yii::$app->user->logout();

            return [
                'menu' => '<a onclick="authentication()">Вход</a>',
                '_csrf' => Yii::$app->request->getCsrfToken()
            ];
        }

        Yii::$app->response->redirect('/');
    }

    /**
     * Login action.
     *
     * @return Response|string
     */
    public function actionRegistration()
    {
        $model = new AccountForm(Yii::$app->request->post()['AccountForm'] ?? Yii::$app->request->get()['AccountForm'] ?? null);
        $model->type = 0;

        if (Yii::$app->request->isAjax) {
            // AJAX-POST-запрос

            Yii::$app->response->format = Response::FORMAT_JSON;

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже аутентифицирован
                Yii::$app->response->statusCode = 302;
                return [
                    'form' => $this->renderPartial('index'),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }

            if ($model->registration()) {
                // Данные прошли проверку и аккаунт был создан

                return [
                    'menu' => <<<HTML
                        <p class="m-0">
                            <a class="text-dark" href="/cart"><i class="fas fa-shopping-cart mr-4"></i></a>
                            <a class="text-dark" href="/orders"><i class="fas fa-list mr-4"></i></a>
                            <a class="text-dark" onclick="deauthentication()">Выход ($model->mail)</a>
                        </p>
                    HTML,
                    'form' => $this->renderPartial('index'),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            } else {
                // Данные не прошли проверку

                Yii::$app->response->statusCode = 400;

                return [
                    'form' => $this->renderPartial('account', compact('model')),
                    '_csrf' => Yii::$app->request->getCsrfToken()
                ];
            }
        } else if (Yii::$app->request->isPost) {
            // POST-запрос
            return;
        } else {
            // GET-запрос и прочие

            if (!Yii::$app->user->isGuest) {
                // Аккаунт уже аутентифицирован
                Yii::$app->response->redirect('/');
            }
        }

        return $this->render('registration', compact('model'));
    }

    /**
     * Displays профиль
     *
     * @return Response|string
     */
    public function actionProfile()
    {
        $model = new Account();

        return $this->render('profile', compact('model'));
    }

    /**
     * Displays contact page.
     *
     * @return Response|string
     */
    public function actionContact()
    {
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post()) && $model->contact(Yii::$app->params['adminEmail'])) {
            Yii::$app->session->setFlash('contactFormSubmitted');

            return $this->refresh();
        }
        return $this->render('contact', [
            'model' => $model,
        ]);
    }

    /**
     * Displays about page.
     *
     * @return string
     */
    public function actionAbout()
    {
        return $this->render('about');
    }
}
